Class: WebbyNode::Client
- Defined in:
- lib/webbynode-api/data.rb
Overview
Represents the account-holder’s information
Instance Attribute Summary
Attributes inherited from APIObject
Instance Method Summary collapse
-
#initialize(options = {}) ⇒ Client
constructor
Fills the @data variable with a hash of information about the client.
Methods inherited from APIObject
#auth_get, #auth_post, auth_post, #method_missing
Constructor Details
#initialize(options = {}) ⇒ Client
Fills the @data variable with a hash of information about the client.
15 16 17 18 |
# File 'lib/webbynode-api/data.rb', line 15 def initialize( = {}) super() @data = auth_get("/api/xml/client")["hash"]["client"] end |
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class WebbyNode::APIObject